@@ -34,14 +34,14 @@
 
 archive::archive(FILE *stream) : f(stream) {
 
-  assert(f, "Data file not found");
+  assert(f, _("Data file not found"));
 
   /* find out the number of files inside the archive
    * alloce the neccessary memory
    */
   fread(&filecount, 1, 1, f);
   files = new fileindex[filecount];
-  assert(files, "Failed to alloc memory for archive index.");
+  assert(files, _("Failed to alloc memory for archive index."));
 
   /* read the information for each file */
   for (Uint8 file = 0; file < filecount; file++) {
@@ -55,7 +55,7 @@ archive::archive(FILE *stream) : f(stream) {
 
       do {
         strlen++;
-        assert(strlen <= FNAMELEN, "Filename too long, datafile corrupt?");
+        assert(strlen <= FNAMELEN, _("Filename too long, datafile corrupt?"));
         fread(&c, 1, 1, f);
       } while (c);
 
@@ -130,8 +130,8 @@ file::file(const archive *arc, const char *name) : bufferpos(0) {
       fread(b, arc->files[i].compress, 1, arc->f);
 
       /* decompress it and check results */
-      assert(uncompress(buffer, &fsize, b, arc->files[i].compress) == Z_OK, "Decompression problem, data file corrupt?");
-      assert(fsize == arc->files[i].size, "Data file corrupt.");
+      assert(uncompress(buffer, &fsize, b, arc->files[i].compress) == Z_OK, _("Decompression problem, data file corrupt?"));
+      assert(fsize == arc->files[i].size, _("Data file corrupt."));
 
       /* free temporary buffer */
       delete [] b;
@@ -141,10 +141,10 @@ file::file(const archive *arc, const char *name) : bufferpos(0) {
   }
 
   /* if we arrive here we couldn't find the file we looked for */
-  assert(0, "File not found in archive!");
+  assert(0, _("File not found in archive!"));
 }
 
-file::~file() { delete(buffer); }
+file::~file() { delete [] buffer; }
 
 Uint32 file::read(void *buf, Uint32 size) {
   memcpy(buf, &buffer[bufferpos], size);
