@@ -82,16 +82,16 @@ void gam_arrival(void) {
   do {
     scr_drawall(8, 0, lev_towertime(), svisible, subshape, substart, SF_NONE);
     scr_darkenscreen();
-    scr_writetext_center((SCREENHEI / 6), "You are entering the");
+    scr_writetext_center((SCREENHEI / 6), _("You are entering the"));
 
     if (strlen(lev_towername()))
-      scr_writetext_center((SCREENHEI*2 / 6), lev_towername());
+      scr_writetext_center((SCREENHEI*2 / 6), gettext(lev_towername()));
     else
-      scr_writetext_center((SCREENHEI*2 / 6), "Nameless Tower");
+      scr_writetext_center((SCREENHEI*2 / 6), _("Nameless Tower"));
 
     if (passwd && lev_show_passwd(lev_towernr())) {
       char buf[50];
-      snprintf(buf, 50, "Password:   %s", passwd);
+      snprintf(buf, 50, _("Password:   %s"), passwd);
       scr_writetext_center(SCREENHEI * 5 / 6, buf);
     }
     scr_swap();
@@ -296,11 +296,13 @@ static void timeout(int &tower_position, int &tower_anglepos) {
   bg_tower_pos = tower_position;
   bg_tower_angle = tower_anglepos;
   bg_time = 0;
+
+  set_men_bgproc(game_background_proc);
    
-  men_info("Time over", 150);
+  men_info(_("Time over"), 150);
 }
 
-static void writebonus(int &tower_position, int tower_anglepos, int zeit, int tec, int extra, int time) {
+static void writebonus(int &tower_position, int tower_anglepos, int zeit, int tec, int extra, int time, int lif, bool lifes) {
   char s[30];
 
   scr_drawall(towerpos(top_verticalpos(), tower_position,
@@ -308,74 +310,97 @@ static void writebonus(int &tower_position, int tower_anglepos, int zeit, int te
 
   scr_darkenscreen();
 
-  snprintf(s, 30, "Time:      ~t35010 X %3d", zeit);
-  scr_writeformattext(90, (SCREENHEI / 2) - FONTHEI * 3, s);
-  snprintf(s, 30, "Technique: ~t35010 X %3d", tec);
-  scr_writeformattext(90, (SCREENHEI / 2), s);
-  snprintf(s, 30, "Extra:     ~t35010 X %3d", extra);
-  scr_writeformattext(90, (SCREENHEI / 2) + FONTHEI * 3, s);
+  if (lifes) {
+    snprintf(s, 30, _("Time:      ~t35010 X %3d"), zeit);
+    scr_writeformattext(90, (SCREENHEI / 2) - FONTHEI * 3, s);
+    snprintf(s, 30, _("Technique: ~t35010 X %3d"), tec);
+    scr_writeformattext(90, (SCREENHEI / 2) - FONTHEI, s);
+    snprintf(s, 30, _("Extra:     ~t35010 X %3d"), extra);
+    scr_writeformattext(90, (SCREENHEI / 2) + FONTHEI, s);
+    snprintf(s, 30, _("Lifes:     ~t3505000 X %3d"), lif);
+    scr_writeformattext(90, (SCREENHEI / 2) + FONTHEI * 3, s);
+  } else {
+    snprintf(s, 30, _("Time:      ~t35010 X %3d"), zeit);
+    scr_writeformattext(90, (SCREENHEI / 2) - FONTHEI * 3, s);
+    snprintf(s, 30, _("Technique: ~t35010 X %3d"), tec);
+    scr_writeformattext(90, (SCREENHEI / 2), s);
+    snprintf(s, 30, _("Extra:     ~t35010 X %3d"), extra);
+    scr_writeformattext(90, (SCREENHEI / 2) + FONTHEI * 3, s);
+  }
 
   scr_swap();
 }
 
-static void countdown(int &s) {
+static void countdown(int &s, int factor) {
   if (s >= 100) {
     s -= 100;
-    pts_add(1000);
+    pts_add(100*factor);
     return;
   }
   if (s >= 10) {
     s -= 10;
-    pts_add(100);
+    pts_add(10*factor);
     return;
   }
   if (s >= 1) {
     (s)--;
-    pts_add(10);
+    pts_add(factor);
     return;
   }
 }
 
-static void bonus(int &tower_position, int &tower_angle, int time) {
+static void bonus(int &tower_position, int &tower_angle, int time, bool lifes) {
+
   int zeit, tec, extra, delay = 0;
+  int lif = pts_lifes();
 
   zeit = time / 10;
   extra = 100;
   tec = top_technic();
 
   do {
-     writebonus(tower_position, tower_angle, zeit, tec, extra, time);
+     writebonus(tower_position, tower_angle, zeit, tec, extra, time, lif, lifes);
      dcl_wait();
   } while ((delay++ < 80) && !key_keypressed(fire_key));
 
   while (zeit > 0) {
     dcl_wait();
-    countdown(zeit);
+    countdown(zeit, 10);
     snd_score();
     snd_play();
-    writebonus(tower_position, tower_angle, zeit, tec, extra, time);
+    writebonus(tower_position, tower_angle, zeit, tec, extra, time, lif, lifes);
   }
 
   while (tec > 0) {
     dcl_wait();
-    countdown(tec);
+    countdown(tec, 10);
     snd_score();
     snd_play();
-    writebonus(tower_position, tower_angle, zeit, tec, extra, time);
+    writebonus(tower_position, tower_angle, zeit, tec, extra, time, lif, lifes);
   }
 
   while (extra > 0) {
     dcl_wait();
-    countdown(extra);
+    countdown(extra, 10);
     snd_score();
     snd_play();
-    writebonus(tower_position, tower_angle, zeit, tec, extra, time);
+    writebonus(tower_position, tower_angle, zeit, tec, extra, time, lif, lifes);
+  }
+
+  if (lifes) {
+    while (lif > 0) {
+      dcl_wait();
+      countdown(lif, 5000);
+      snd_score();
+      snd_play();
+      writebonus(tower_position, tower_angle, zeit, tec, extra, time, lif, lifes);
+    }
   }
    
   delay = 0;
 
   do {
-     writebonus(tower_position, tower_angle, zeit, tec, extra, time);
+     writebonus(tower_position, tower_angle, zeit, tec, extra, time, lif, lifes);
      dcl_wait();
   } while ((delay++ < 30) && (!key_keypressed(fire_key)));
 }
@@ -452,7 +477,7 @@ static void pause(int &tower_position, int tower_anglepos, int time) {
   bg_time = time;
    
   set_men_bgproc(game_background_proc);
-  men_info("Pause", -1, 1);
+  men_info(_("Pause"), -1, 1);
 
   snd_wateron();
   towerpos(top_verticalpos(), tower_position,
@@ -492,7 +517,7 @@ gam_result gam_towergame(Uint8 &anglepos, Uint16 &resttime, int &demo, void *dem
   if (demo < 0) drawflags = SF_REC;
   else if (demo > 0) drawflags = SF_DEMO;
 
-  assert(!(demo && !demobuf), "Trying to play or record a null demo.");
+  assert(!(demo && !demobuf), _("Trying to play or record a null demo."));
 
 
   top_init();
@@ -571,7 +596,7 @@ gam_result gam_towergame(Uint8 &anglepos, Uint16 &resttime, int &demo, void *dem
   } while (!top_ended() && (state == STATE_PLAYING));
 
   if (top_targetreached() && !demo) {
-    bonus(tower_position, tower_angle, time);
+    bonus(tower_position, tower_angle, time, lev_lasttower());
     rob_disappearall();
 
     for (int i = 0; i < 6; i++) {
