@@ -122,9 +122,10 @@ static int missionfiles (const struct dirent *file)
           (file->d_name[len - 4] == '.'));
 }
 
-Uint8 conv_char2towercode(char ch) {
+Uint8 conv_char2towercode(wchar_t ch) {
   if (ch)
     for (int x = 0; x < NUM_TBLOCKS; x++)
+      // we can do that because we use only chars below 128
       if (ch == towerblockdata[x].ch) return x;
   return TB_EMPTY;
 }
@@ -588,6 +589,10 @@ Uint8 lev_towernr(void) {
   return towernumber;
 }
 
+bool lev_lasttower(void) {
+  return (towernumber+1) == lev_towercount();
+}
+
 Uint8 lev_robotnr(void) {
   return towerrobot;
 }
@@ -1261,7 +1266,7 @@ static Uint8 nmission = 0;
 static Uint32 missionidx[256];
 
 bool lev_mission_new(char * name, Uint8 prio) {
-  assert(!fmission, "called mission_finish twice");
+  assert(!fmission, _("called mission_finish twice"));
 
   char fname[200];
   snprintf(fname, 200, "%s.ttm", name);
@@ -1302,7 +1307,7 @@ void write_fmission_section(Uint8 section, Uint32 section_len) {
 }
 
 void lev_mission_addtower(char * name) {
-  assert(fmission, "called mission_addtower without mission_new");
+  assert(fmission, _("called mission_addtower without mission_new"));
 
   Uint8 rows, col;
   Sint16 row;
@@ -1432,7 +1437,7 @@ void lev_mission_addtower(char * name) {
 }
 
 void lev_mission_finish() {
-  assert(fmission, "called mission_finish without mission_new");
+  assert(fmission, _("called mission_finish without mission_new"));
 
   Uint8 c;
 
