@@ -85,7 +85,7 @@ Uint16 lev_missionnumber();
 const char * lev_missionname(Uint16 num);
 
 /* Convert a char into towerblock */
-Uint8 conv_char2towercode(char ch);
+Uint8 conv_char2towercode(wchar_t ch);
   
 /* Get tower password. Note that the password changes when
    the tower changes. */
@@ -138,6 +138,9 @@ void lev_get_towerdemo(int &demolen, Uint16 *&demobuf);
 /* the number of the actual tower */
 Uint8 lev_towernr(void);
 
+/* returns true, if current tower is the last one */
+bool lev_lasttower(void);
+
 /* the number of the robot used */
 Uint8 lev_robotnr(void);
 void lev_set_robotnr(Uint8 robot);
