@@ -33,6 +33,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <math.h>
+#include <wchar.h>
 
 static SDL_Surface *display;
 
@@ -81,7 +82,7 @@ static struct {
   Uint8 *data[3];      // the data for the 3 layers of the door (pixel info for recoloring)
 } doors[73];
 
-#define MAXCHARNUM 128
+#define MAXCHARNUM 256*256
 
 static struct {
   unsigned short s;
@@ -131,10 +132,50 @@ scr_savedisplaybmp(char *fname)
   SDL_SaveBMP(display, fname);
 }
 
+/*
+ * Set the pixel at (x, y) to the given value
+ * NOTE: The surface must be locked before calling this!
+ */
+void putpixel(SDL_Surface *surface, int x, int y, Uint32 pixel)
+{
+  int bpp = surface->format->BytesPerPixel;
+  /* Here p is the address to the pixel we want to set */
+  Uint8 *p = (Uint8 *)surface->pixels + y * surface->pitch + x * bpp;
+
+  switch(bpp) {
+    case 1:
+      *p = pixel;
+      break;
+
+    case 2:
+      *(Uint16 *)p = pixel;
+      break;
+
+    case 3:
+      if(SDL_BYTEORDER == SDL_BIG_ENDIAN) {
+        p[0] = (pixel >> 16) & 0xff;
+        p[1] = (pixel >> 8) & 0xff;
+        p[2] = pixel & 0xff;
+        } else {
+        p[0] = pixel & 0xff;
+        p[1] = (pixel >> 8) & 0xff;
+        p[2] = (pixel >> 16) & 0xff;
+        }
+        break;
+
+    case 4:
+        *(Uint32 *)p = pixel;
+        break;
+  }
+}
+
+
+
 Uint16 scr_loadsprites(spritecontainer *spr, file * fi, int num, int w, int h, bool sprite, const Uint8 *pal, bool use_alpha) {
   Uint16 erg = 0;
   Uint8 b, a;
   SDL_Surface *z;
+  Uint32 pixel;
 
   for (int t = 0; t < num; t++) {
     z = SDL_CreateRGBSurface(SDL_SWSURFACE | (sprite) ? SDL_SRCALPHA : 0,
@@ -146,47 +187,31 @@ Uint16 scr_loadsprites(spritecontainer *spr, file * fi, int num, int w, int h, b
     for (int y = 0; y < h; y++)
       for (int x = 0; x < w; x++) {
         b = fi->getbyte();
-#if (SDL_BYTEORDER == SDL_LIL_ENDIAN)
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 0] = pal[b*3 + 2];
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 1] = pal[b*3 + 1];
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 2] = pal[b*3 + 0];
-#else
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 3] = pal[b*3 + 2];
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 2] = pal[b*3 + 1];
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 1] = pal[b*3 + 0];
-#endif
+        pixel=SDL_MapRGB(z->format,pal[b*3 + 0],pal[b*3 + 1],pal[b*3 + 2]);
         if (sprite) {
           a = fi->getbyte();
-          if (use_alpha)
-#if (SDL_BYTEORDER == SDL_LIL_ENDIAN)
-            ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 3] = a;
-#else
-            ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 0] = a;
-#endif
-          else {
-            /* ok, this is the case where we have a sprite and don't want
-             to use alpha blending, so we use normal sprites with key color
-             instead, this is much faster. So if the pixel is more than 50% transparent
-             make the whole pixel transparent by setting this pixel to the
-             key color. if the pixel is not supoosed to be transparent
-             we need to check if the pixel color is by accident the key color,
-             if so we alter is slightly */
-            if (a < 128) {
-#if (SDL_BYTEORDER == SDL_LIL_ENDIAN)
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 0] = 1;
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 1] = 1;
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 2] = 1;
-#else
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 3] = 1;
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 2] = 1;
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 1] = 1;
-#endif
-            }  else {
+          if (use_alpha) {
+            pixel=SDL_MapRGBA(z->format,pal[b*3 + 0],pal[b*3 + 1],pal[b*3 + 2],a);
+          } else {
+            if (a<128)
+              pixel=SDL_MapRGB(z->format,1,1,1);
+            else
+            {
               if ((pal[b*3+2] == 1) && (pal[b*3+1] == 1) || (pal[b*3] == 1))
-                ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 2]++;
+                pixel=SDL_MapRGB(z->format,pal[b*3 + 0],pal[b*3 + 1],pal[b*3 + 2]+1);
+              else
+                /* ok, this is the case where we have a sprite and don't want
+                 to use alpha blending, so we use normal sprites with key color
+                 instead, this is much faster. So if the pixel is more than 50% transparent
+                 make the whole pixel transparent by setting this pixel to the
+                 key color. if the pixel is not supoosed to be transparent
+                 we need to check if the pixel color is by accident the key color,
+                 if so we alter is slightly */
+                pixel=SDL_MapRGB(z->format,pal[b*3 + 0],pal[b*3 + 1],pal[b*3 + 2]);
             }
           }
         }
+        putpixel(z,x,y,pixel);
       }
 
     SDL_Surface * z2 = SDL_DisplayFormatAlpha(z);
@@ -235,6 +260,7 @@ static void scr_regensprites(Uint8 *data, SDL_Surface * const target, int num, i
   Uint8 a, b;
   Uint32 datapos = 0;
   SDL_Surface * z;
+  Uint32 pixel;
 
   if (screenformat) {
     z = SDL_CreateRGBSurface(SDL_SWSURFACE | (sprite && use_alpha) ? SDL_SRCALPHA : 0,
@@ -251,47 +277,31 @@ static void scr_regensprites(Uint8 *data, SDL_Surface * const target, int num, i
     for (int y = 0; y < h; y++)
       for (int x = 0; x < w; x++) {
         b = data[datapos++];
-#if (SDL_BYTEORDER == SDL_LIL_ENDIAN)
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 0] = pal[b*3 + 2];
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 1] = pal[b*3 + 1];
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 2] = pal[b*3 + 0];
-#else
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 3] = pal[b*3 + 2];
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 2] = pal[b*3 + 1];
-        ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 1] = pal[b*3 + 0];
-#endif
+        pixel=SDL_MapRGB(z->format,pal[b*3 + 0],pal[b*3 + 1],pal[b*3 + 2]);
         if (sprite) {
           a = data[datapos++];
           if (use_alpha) {
-#if (SDL_BYTEORDER == SDL_LIL_ENDIAN)
-            ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 3] = a;
-#else
-            ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 0] = a;
-#endif
+            pixel=SDL_MapRGBA(z->format,pal[b*3 + 0],pal[b*3 + 1],pal[b*3 + 2],a);
           } else {
-            /* ok, this is the case where we have a sprite and don't want
-             to use alpha blending, so we use normal sprites with key color
-             instead, this is much faster. So if the pixel is more than 50% transparent
-             make the whole pixel transparent by setting this pixel to the
-             key color. if the pixel is not supoosed to be transparent
-             we need to check if the pixel color is by accident the key color,
-             if so we alter is slightly */
-            if (a < 128) {
-#if (SDL_BYTEORDER == SDL_LIL_ENDIAN)
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 0] = 1;
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 1] = 1;
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 2] = 1;
-#else
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 3] = 1;
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 2] = 1;
-              ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 1] = 1;
-#endif
-            }  else {
+            if (a<128)
+              pixel=SDL_MapRGB(z->format,1,1,1);
+            else
+            {
               if ((pal[b*3+2] == 1) && (pal[b*3+1] == 1) || (pal[b*3] == 1))
-                ((Uint8 *)(z->pixels))[y*z->pitch+x*z->format->BytesPerPixel + 2]++;
+                pixel=SDL_MapRGB(z->format,pal[b*3 + 0],pal[b*3 + 1],pal[b*3 + 2]+1);
+              else
+                /* ok, this is the case where we have a sprite and don't want
+                 to use alpha blending, so we use normal sprites with key color
+                 instead, this is much faster. So if the pixel is more than 50% transparent
+                 make the whole pixel transparent by setting this pixel to the
+                 key color. if the pixel is not supoosed to be transparent
+                 we need to check if the pixel color is by accident the key color,
+                 if so we alter is slightly */
+                pixel=SDL_MapRGB(z->format,pal[b*3 + 0],pal[b*3 + 1],pal[b*3 + 2]);
             }
           }
         }
+        putpixel(z,x,y,pixel);
       }
   if (screenformat) {
     SDL_Rect r;
@@ -506,7 +516,7 @@ void scr_setcrosscolor(Uint8 rk, Uint8 gk, Uint8 bk) {
 static void loadfont(void) {
 
   unsigned char pal[256*3];
-  Uint8 c;
+  Uint16 c;
   int fontheight;
 
   file fi(&dataarchive, fontdat);
@@ -516,7 +526,7 @@ static void loadfont(void) {
   fontheight = fi.getbyte();
 
   while (!fi.eof()) {
-    c = fi.getbyte();
+    c = fi.getword();
 
     if (!c || (c >= MAXCHARNUM)) break;
 
@@ -537,10 +547,10 @@ static void loadscroller(void) {
 
   num_scrolllayers = layers;
 
-  assert(num_scrolllayers > 1, "Must have at least 2 scroll layers!");
+  assert(num_scrolllayers > 1, _("Must have at least 2 scroll layers!"));
 
   scroll_layers = new _scroll_layer[layers];
-  assert(scroll_layers, "Failed to alloc memory for bonus scroller!");
+  assert(scroll_layers, _("Failed to alloc memory for bonus scroller!"));
     
   towerpos = fi.getbyte();
     
@@ -622,7 +632,7 @@ void scr_init(void) {
 
 void scr_reinit() {
   display = SDL_SetVideoMode(SCREENWID, SCREENHEI, 16, (config.fullscreen()) ? (SDL_FULLSCREEN) : (0));
-  assert(display, "could not open display");
+  assert(display, _("could not open display"));
 }
 
 void scr_done(void) {
@@ -817,22 +827,28 @@ static void putwater(long height) {
 int scr_textlength(const char *s, int chars) {
   int len = 0;
   int pos = 0;
-  unsigned char c;
+  mbstate_t state;
+  memset (&state, '\0', sizeof (state));
+  wchar_t tmp;
 
   while (s[pos] && (chars > 0)) {
-    if (s[pos] == ' ') {
+
+    size_t nbytes = mbrtowc (&tmp, &s[pos], chars, &state);
+    if (nbytes <= 0)
+      return 0;
+
+    if (tmp == ' ') {
       len += FONTMINWID;
     } else {
-      c = s[pos];
-      if (fontchars[c].width != 0)
-        len += fontchars[c].width + 3;
+      if (fontchars[tmp & 0xffff].width != 0)
+        len += fontchars[tmp & 0xffff].width + 3;
     }
     pos++;
 
     chars--;
   }
 
-  return len - 1;
+  return len;
 }
 
 void scr_writetext_center(long y, const char *s) {
@@ -1125,6 +1141,7 @@ static void putrobot(int t, int m, long x, long h)
   
     case OBJ_KIND_FREEZEBALL:
     case OBJ_KIND_FREEZEBALL_FROZEN:
+    case OBJ_KIND_FREEZEBALL_FALLING:
       nr = ballst + 1;
       break;
   
@@ -1150,115 +1167,248 @@ static void putrobot(int t, int m, long x, long h)
 }
 
 void scr_writetext(long x, long y, const char *s, int maxchars) {
+
+  mbstate_t state;
+  memset (&state, '\0', sizeof (state));
+  wchar_t tmp;
+
   int t = 0;
-  unsigned char c;
-  while (s[t] && (maxchars-- != 0)) {
-    if (s[t] == ' ') {
+
+  if (maxchars == -1)
+    maxchars = strlen(s);
+
+  while (s[t] && (maxchars > 0)) {
+
+    size_t nbytes = mbrtowc (&tmp, &s[t], maxchars, &state);
+
+    if (nbytes >= (size_t) -2) {
+      return;
+    }
+
+    if (tmp == ' ') {
       x += FONTMINWID;
-      t++;
+      t += nbytes;
+      maxchars -= nbytes;
       continue;
     }
 
-    c = s[t];
-    if (fontchars[c].width != 0) {
-      scr_blit(fontsprites.data(fontchars[c].s), x, y);
-      x += fontchars[c].width + 3;
+    if (fontchars[tmp & 0xffff].width != 0) {
+      scr_blit(fontsprites.data(fontchars[tmp & 0xffff].s), x, y-20);
+      x += fontchars[tmp & 0xffff].width + 3;
     }
-    t++;
+
+    t += nbytes;
+    maxchars -= nbytes;
   }
 }
 
 void scr_writeformattext(long x, long y, const char *s) {
 
+  mbstate_t state;
+  memset (&state, '\0', sizeof (state));
+  wchar_t tmp;
+
+  size_t len = strlen(s);
+
   int origx = x;
-  int t = 0;
+  size_t t = 0;
   Uint8 towerblock = 0;
-  unsigned char c;
-  while (s[t]) {
-    switch(s[t]) {
+  while (t < len) {
+
+    size_t nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+
+    if (nbytes >= (size_t) -2) {
+      return;
+    }
+
+    t += nbytes;
+
+    switch(tmp) {
     case ' ':
       x += FONTMINWID;
-      t++;
       break;
     case '~':
-      switch(s[t+1]) {
+
+      nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+      if (nbytes >= (size_t) -2) {
+        return;
+      }
+      t += nbytes;
+
+      switch(tmp) {
       case 't':
-        x = (s[t+2] - '0') * 100 + (s[t+3] - '0') * 10 + (s[t+4] - '0');
-        t += 5;
+
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) {
+          return;
+        }
+        t += nbytes;
+
+        x = (tmp - '0') * 100;
+
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) {
+          return;
+        }
+        t += nbytes;
+
+        x += (tmp - '0') * 10;
+
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) {
+          return;
+        }
+        t += nbytes;
+
+        x += (tmp - '0');
+
         break;
       case 'T':
-	x = origx + (s[t+2] - '0') * 100 + (s[t+3] - '0') * 10 + (s[t+4] - '0');
-	t += 5;
-	break;
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) {
+          return;
+        }
+        t += nbytes;
+
+        x = origx + (tmp - '0') * 100;
+
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) {
+          return;
+        }
+        t += nbytes;
+
+        x += (tmp - '0') * 10;
+
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) {
+          return;
+        }
+        t += nbytes;
+
+        x += (tmp - '0');
+
+        break;
       case 'b':
-	towerblock = conv_char2towercode(s[t+2]);
-	putcase(towerblock, x+16, y);
-	x += 32;
-	t += 3;
-	break;
+
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) {
+          return;
+        }
+        t += nbytes;
+
+        towerblock = conv_char2towercode(tmp);
+        putcase(towerblock, x+16, y);
+        x += 32;
+        break;
       case 'e':
-	towerblock = conv_char2towercode(s[t+2]);
-	putcase_editor(towerblock, x+16, y, boxstate);
-	x += 32;
-	t += 3;
-	break;
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) {
+          return;
+        }
+        t += nbytes;
+
+        towerblock = conv_char2towercode(tmp);
+        putcase_editor(towerblock, x+16, y, boxstate);
+        x += 32;
+        break;
       default:
-        assert(0, "Wrong command in formatted text.");
-        t += 2;
+        assert(0, _("Wrong command in formatted text."));
       }
       break;
     default:
-      c = s[t];
-      if (fontchars[c].width != 0) {
-        scr_blit(fontsprites.data(fontchars[c].s), x, y);
-        x += fontchars[c].width + 3;
+      if (fontchars[tmp & 0xffff].width != 0) {
+        scr_blit(fontsprites.data(fontchars[tmp & 0xffff].s), x, y-20);
+        x += fontchars[tmp & 0xffff].width + 3;
       }
-      t++;
     }
   }
 }
 
 long scr_formattextlength(long x, long y, const char *s) {
+  mbstate_t state;
+  memset (&state, '\0', sizeof (state));
+  wchar_t tmp;
+
+  size_t len = strlen(s);
+
   int origx = x;
-  int t = 0;
-  unsigned char c;
-  while (s[t]) {
-    switch(s[t]) {
+  size_t t = 0;
+  while (t < len) {
+
+    size_t nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+    if (nbytes >= (size_t) -2) return 0;
+    t += nbytes;
+
+    switch(tmp) {
     case ' ':
       x += FONTMINWID;
-      t++;
       break;
     case '~':
-      switch(s[t+1]) {
+
+      nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+      if (nbytes >= (size_t) -2) return 0;
+      t += nbytes;
+
+      switch(tmp) {
       case 't':
-        x = (s[t+2] - '0') * 100 + (s[t+3] - '0') * 10 + (s[t+4] - '0');
-        t += 5;
+
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) return 0;
+        t += nbytes;
+        x = (tmp - '0') * 100;
+
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) return 0;
+        t += nbytes;
+        x += (tmp - '0') * 10;
+
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) return 0;
+        t += nbytes;
+        x += (tmp - '0');
+
         break;
       case 'T':
-	x = origx + (s[t+2] - '0') * 100 + (s[t+3] - '0') * 10 + (s[t+4] - '0');
-	t += 5;
-	break;
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) return 0;
+        t += nbytes;
+        x = origx + (tmp - '0') * 100;
+
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) return 0;
+        t += nbytes;
+        x += (tmp - '0') * 10;
+
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) return 0;
+        t += nbytes;
+        x += (tmp - '0');
+
+        break;
       case 'b':
-	x += 32;
-	t += 3;
-	break;
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) return 0;
+        t += nbytes;
+        x += 32;
+        break;
       case 'e':
-	x += 32;
-	t += 3;
-	break;
+        nbytes = mbrtowc (&tmp, &s[t], len-t, &state);
+        if (nbytes >= (size_t) -2) return 0;
+        t += nbytes;
+        x += 32;
+        break;
       default:
-        assert(0, "Wrong command in formatted text, scr_formattextlength.");
-        t += 2;
+        assert(0, _("Wrong command in formatted text."));
       }
       break;
     default:
-      c = s[t];
-      if (fontchars[c].width != 0) {
-        x += fontchars[c].width + 3;
+      if (fontchars[tmp & 0xffff].width != 0) {
+        x += fontchars[tmp & 0xffff].width + 3;
       }
-      t++;
     }
   }
+
   return (x-origx);
 }
 
@@ -1418,8 +1568,8 @@ static void draw_data(int time, screenflag flags)
 
   y = config.status_top() ? SCREENHEI - FONTHEI : 5;
   switch (flags) {
-    case SF_REC:  if (!(boxstate & 8)) scr_writetext_center(y, "REC"); break;
-    case SF_DEMO: scr_writetext_center(y, "DEMO"); break;
+    case SF_REC:  if (!(boxstate & 8)) scr_writetext_center(y, _("REC")); break;
+    case SF_DEMO: scr_writetext_center(y, _("DEMO")); break;
     case SF_NONE:
     default:      break;
   }
